//=============================================================================
// DawnsLoopMover1.  By Dawn Knight 09/16/2003
// $DateTime: Fri, 09/19/2003 10:42:08 am$
//=============================================================================
class DawnsLoopMover1 extends Mover;

// When the last keyframe position is reached, this mover
// snaps instantly to the first keyframe (directly, not through
// the intermediate frames), and repeats the movement forever.
// For use when last keyframe == first keyframe to prevent
// interpolation between them.
// In other words: Last keyframe MUST EQUAL first keyframe!

var int NextKeyNum;

function BeginPlay()
{
	KeyNum = 0;
	MoveTime = FMin(MoveTime, 100);
	Super.BeginPlay();
}

final function DoOpen1()
{
	// Move to the next keyframe.
	bOpening = true;
	bDelaying = false;
	if (NextKeyNum == 0)
		InterpolateTo1( 0, 0.0 ); // instant jump from Last to First keyframe
	else
		InterpolateTo1( NextKeyNum, MoveTime );
	AmbientSound = MoveAmbientSound;
}

// Interpolate to keyframe KeyNum in Seconds time.
final function InterpolateTo1( byte NewKeyNum, float Seconds )
{
	OldPos    = Location;
	OldRot    = Rotation;
	PhysAlpha = 0.0;

	SetPhysics(PHYS_MovingBrush);
	bInterpolating   = true;
	PrevKeyNum       = KeyNum;
	KeyNum			 = NewKeyNum;
	PhysRate         = 1.0 / Seconds;

	ClientUpdate++;
	SimOldPos = OldPos;
	SimOldRotYaw = OldRot.Yaw;
	SimOldRotPitch = OldRot.Pitch;
	SimOldRotRoll = OldRot.Roll;
	SimInterpolate.X = 100 * PhysAlpha;
	SimInterpolate.Y = 100 * PhysRate;
	SimInterpolate.Z = 256 * PrevKeyNum + KeyNum;
}

state() LoopMove
{
	function Trigger( actor Other, pawn EventInstigator )
	{
		SavedTrigger = Other;
		Instigator = EventInstigator;
		SavedTrigger.BeginEvent();
		SetPhysics(PHYS_MovingBrush);
		GotoState( 'LoopMove', 'Open' );
	}

	function UnTrigger( actor Other, pawn EventInstigator )
	{
	}

	function InterpolateEnd(actor Other)
	{
	}

	function BeginState()
	{
		bOpening = false;
	}

Open:
	Disable ('Trigger');
	NextKeyNum = KeyNum + 1;
	if( NextKeyNum >= NumKeys )
		NextKeyNum = 0;
	bOpening = true;
	bDelaying = false;

	if( NextKeyNum >= NumKeys ) NextKeyNum = 0;
	DoOpen1();

	AmbientSound = MoveAmbientSound;
	FinishInterpolation();

	// Loop forever
	GotoState( 'LoopMove', 'Open' );

InactiveState:
	DoOpen1();
	FinishInterpolation();
	FinishedOpening();
	Stop;
}

// obj load file=DawnsMapTools.u Package=MyLevel

defaultproperties
{
     MoverEncroachType=ME_CrushWhenEncroach
     MoverGlideType=MV_MoveByTime
     InitialState=LoopMove
     SoundVolume=255
     TransientSoundVolume=20.000000
}
