//=============================================================================
// DawnsScopeCam for UT.  By Dawn Knight  Version 1.03 09/08/2004
//
// A Camera aimed by the PlayerPawn Owning it.  Intended to be used with a
// ScopeCamTrigger, which Spawns this DawnsScopeCam.
//=============================================================================
class DawnsScopeCam extends Keypoint;

var bool bSkipView; // spectators skip this camera when flipping through cams.
var float FadeOutTime;	// fade out time if used as EndCam.
var ScopeCamTrigger SCT; // set by associated ScopeCamTrigger

var TournamentPlayer MyPlayer;

// This is always 'none' on Clients:
var TournamentPlayer Master; // This Player is using this DawnsScopeCam.

var bool bOriBehindView;
var ZoomScope2 ZS;
var Weapon MasterLastWeapon;
var Inventory OldInventory; // Hide Inventory to prevent switching when viewing

// Network replication.
replication
{
	// Things the Server should send to the Client.
	reliable if( bNetOwner && (Role==ROLE_Authority) )
		SCT;
}

function PostBeginPlay()
{
	local string ZoomScopeClass;

	// Does not run on Clients.
	super.PostBeginPlay();
	Master = TournamentPlayer( Owner );
	if( Master == none )
	{
	// Without a TournamentPlayer Master, this DSC is no good.
		SCT = none; // Replicates to Client, telling Client to Destroy its DSC, too.
		Destroy();
		return;
	}
	MyPlayer = TournamentPlayer( Owner );
	if( MyPlayer != none && Viewport( MyPlayer.Player ) != none )
	{
		// The local MyPlayer.Player has possessed this ScopeCam.
		MyPlayer.ViewTarget = self;
		bOriBehindView = MyPlayer.bBehindView;
		MyPlayer.bBehindView = false;
	}
	// Give Player ZoomScope2 and make it the current weapon.
	if( Master.Weapon.IsA( 'ZoomScope2' ) )
		MasterLastWeapon = ZoomScope2( Master.Weapon ).PreviousWeapon;
	else
		MasterLastWeapon = Master.Weapon;
	ZoomScopeClass = Left(string(Level), InStr(string(Level), "."))$".ZoomScope2";
	DeathMatchPlus(Level.Game).GiveWeapon(Master, ZoomScopeClass );
	ZS = ZoomScope2( Master.FindInventoryType(class'ZoomScope2') );
	if( ZS == none )
	{
		Log("**** DSC PostBeginPlay: ZS = None!!!");
	}
	else
	{
		// Don't allow Player to access any of his other Inventory while viewing.
		OldInventory = MyPlayer.Inventory; // Save Player's Inventory away.
		MyPlayer.Inventory = None; // Prevent Player from accessing Inventory.
	}
}

simulated function PostNetBeginPlay()
{
	// Runs only on Clients.
	if( !bNetOwner || ( SCT == none ) )
	{
		// No other Clients need to have this Actor.
		Destroy();
		return;
	}
	MyPlayer = TournamentPlayer( Owner );
	if( MyPlayer != none )
	{
		// The local MyPlayer.Player has possessed this ScopeCam.
		MyPlayer.ViewTarget = self;
		bOriBehindView = MyPlayer.bBehindView;
		MyPlayer.bBehindView = false;
	}
}

simulated function Tick( float DeltaTime )
{
	if( Owner == none )
	{
		// Player stopped possessing.
		Disable( 'Tick' );
		MyPlayer.SetRotation( SCT.Rotation );
		MyPlayer.ViewRotation = SCT.Rotation;
		if( MyPlayer != none &&
				Viewport( MyPlayer.Player ) != none )
		{
			MyPlayer.bBehindView = bOriBehindView;
			MyPlayer.Viewtarget = None;
			MyPlayer.FOVAngle = MyPlayer.Default.DefaultFOV;
			MyPlayer.DesiredFOV = MyPlayer.Default.DefaultFOV;
			MyPlayer.DefaultFOV = MyPlayer.Default.DefaultFOV;
			if( Level.NetMode == NM_Client )
			{
				Destroy();
				return;
			}
		}
		// Begin process of getting rid of ZoomScope2.
		if( Role == ROLE_Authority )
		{
			if( Master != none && Master.Weapon == ZS )
			{
				Master.Inventory = OldInventory; // Return Inventory to Player.
				ZS.PreviousWeapon = MasterLastWeapon;
				ZS.ReturnToPreviousWeapon();
			}
			GoToState( 'DumpingZoomScope2' );
		}
	}
	else
	{
		if( MyPlayer != none )
		{
			// Local Plyr still possessing, so continue to control Player's rot & view.
			MyPlayer.aLookUp = 0;
			MyPlayer.SetRotation( SCT.Rotation ); // Keep Player facing Scope.
			SetRotation( MyPlayer.ViewRotation ); // But control Cam rotation.
		}
	}
}

state DumpingZoomScope2
{

Begin:
	Sleep( 0.75 );
	if( Master != none && ZS != none)
	{
		Master.DeleteInventory( ZS );
		ZS.Destroy();
	}
	Master = none;
	Disable( 'Tick' );
	Destroy();
	GoToState( '' );
}

defaultproperties
{
     bDirectional=True
     bNoDelete=false
     bOwnerNoSee=true
     bSkipView=true
     bStatic=false
     CollisionRadius=8.000000
     CollisionHeight=8.000000
     DrawType=DT_Sprite
     FadeOutTime=0.000000
     RemoteRole=ROLE_SimulatedProxy
     Texture=Texture'Engine.S_Camera'
}
