//=============================================================================
// DawnsStarOrbit.
// Version: 1.0  07/18/2004
// Author: Dawn Knight
//
// Creates the effect of a (blue) Star in an elliptical orbit using a Sprite so
// that it renders the fastest possible.  Only replicates 3 variables one time
// to eliminate any network overhead in gameplay.  Intended as an effect within
// a SkyBox for best results. The Texture used for the Star does not use MipMaps
// because, when used in a SkyBox, the players relation to the Star is constant
// and doesn't need lower res versions of itself.  Uses a Masked Texture.
//
// Since this effect is merely eye candy, doesn't run on Dedicated Servers and
// is not synced up between Clients.
//
// UT Version Coded/Tested: 4.36
//=============================================================================
class DawnsStarOrbit extends Effects;

#exec texture IMPORT NAME=BlueStar FILE=Textures\DDSBlueStar9.PCX FLAGS=2 MIPS=Off MASK=On

var() float XRadius, YRadius;
var vector Center, NewLocation, Normal;
var() int RotRate;
var rotator OrbitAngle, OrbitRate;

replication
{
	// Things the server should send to the client.
	reliable if( Role==ROLE_Authority )
		Center, XRadius, YRadius, RotRate;
}

// Immediately after Effect enters gameplay.
simulated function PreBeginPlay()
{
	Super.PreBeginPlay();
	if ( Level.NetMode != NM_Client )
	{
		Center = Location; // Before getting X Offset...
		Center.X = Center.X - XRadius; // Center of ellipse
		InitOrbit();
	}
}

// Immediately after effect vars are replicated to Clients.
simulated function PostNetBeginPlay()
{
	Super.PostNetBeginPlay();
	if ( Level.NetMode == NM_Client )
		InitOrbit();
}

simulated function InitOrbit()
{
	Center = Center; // Center of ellipse
	OrbitRate.Yaw = RotRate;
}

simulated function Tick( float DeltaTime )
{
	if ( Level.NetMode != NM_DedicatedServer )
	{
		OrbitAngle += (OrbitRate * DeltaTime);
		Normal = vector(OrbitAngle);
		Normal.X = Normal.X * XRadius;
		Normal.Y = Normal.Y * YRadius;
		NewLocation = Center + Normal;
		SetLocation(NewLocation);
	}
}

defaultproperties
{
     bAlwaysRelevant=True
     bEdShouldSnap=True
     bHidden=False
		 bMovable=True
     bNetTemporary=False
     bStatic=False
     DrawType=DT_Sprite
     Sprite=Texture'DawnsDeepSpace.BlueStar'
     Texture=Texture'DawnsDeepSpace.BlueStar'
     Skin=Texture'DawnsDeepSpace.BlueStar'
     RemoteRole=ROLE_SimulatedProxy
}
