//=============================================================================
// DawnsToggleMover for UT.  08/03/2004 Version 1.01
// Fixes several bugs in ElevatorMover Class.
//
// newMoveTime passed from ElevatorTrigger-type Triggers is actually used now,
// and requires new bool, bUseTriggerMoveTime to be set True. Otherwise,
// MoveTime from this Mover is used.
//
// Looping MoveAmbientSound is now turned off when Mover stops at target
// KeyFrame.
//
// All PlaySound calls now properly use SLOT_None
//=============================================================================
class DawnsToggleMover extends Mover;

// Allows this mover to go from any key frame to any other key frame,
// depending on the trigger settings.

var int   LastKeyNum;
var int   NextKeyNum;
var int   MoveDirection;
var float MoveTimeInterval;
var(Mover) bool  bUseTriggerMoveTime;
var bool  bMoveKey;

function BeginPlay()
{
	Super.BeginPlay();
	bMoveKey = true;
}

function MoveKeyframe( int newKeyNum, float newMoveTime )
{
	if( !bMoveKey ) return;

	NextKeyNum = newKeyNum;
	if( NextKeyNum < KeyNum )
	{
		MoveDirection = -1;
		MoveTimeInterval = newMoveTime/(KeyNum-NextKeyNum);
		GotoState('ToggleTriggerGradual','ChangeFrame');
	}
	if( NextKeyNum > KeyNum )
	{
		MoveDirection = 1;
		MoveTimeInterval = newMoveTime/(NextKeyNum-KeyNum);
		GotoState('ToggleTriggerGradual','ChangeFrame');
	}
}

function DoOpen()
{
	// Open through to the next keyframe.
	bOpening = true;
	bDelaying = false;
	LastKeyNum = KeyNum;
	if( bUseTriggerMoveTime )
		InterpolateTo (KeyNum+1, MoveTimeInterval);
	else
		InterpolateTo (KeyNum+1, MoveTime);
	PlaySound (OpeningSound, SLOT_None);
	AmbientSound = MoveAmbientSound;
}

function DoClose() {

	// Close through to the next keyframe.
	bOpening = false;
	bDelaying = false;
	LastKeyNum = KeyNum;
	if( bUseTriggerMoveTime )
		InterpolateTo (KeyNum-1, MoveTimeInterval);
	else
		InterpolateTo (KeyNum-1, MoveTime);
	PlaySound (ClosingSound, SLOT_None);
	AmbientSound = MoveAmbientSound;
}

state() ToggleTriggerGradual
{
	function InterpolateEnd(actor Other)
	{
	}

	function BeginState()
	{
		bOpening = false;
	}

ChangeFrame:

	bMoveKey = false;
	// Move the mover
	if( MoveDirection > 0	)
	{
		DoOpen();
		FinishInterpolation();
		FinishedClosing();
	}
	else
	{
		DoClose();
		FinishInterpolation();
		FinishedOpening();
	}
	// Check if there are more frames to go
	if( KeyNum != NextKeyNum )
	{
		GotoState('ToggleTriggerGradual','ChangeFrame');
	}
	else
		AmbientSound = None;
	bMoveKey = true;
	Stop;
}

defaultproperties
{
}
