//=============================================================================
// DawnsZoneInfo, fixes Spectators affecting ActorEntered and ActorLeaving.
//=============================================================================
class DawnsZoneInfo extends ZoneInfo;

// When an actor enters this zone.
event ActorEntered( actor Other )
{
	local actor A;
	local vector AddVelocity;

	if ( bNoInventory && Other.IsA('Inventory') && (Other.Owner == None) )
	{
		Other.LifeSpan = 1.5;
		return;
	}
	if( Pawn(Other)!=None && Pawn(Other).bIsPlayer && !Pawn(Other).IsA('Spectator'))
	{
		if( ++ZonePlayerCount==1 )
		{
			SetTimer( 0.5, false );
			if( ZonePlayerEvent!='' )
			foreach AllActors( class 'Actor', A, ZonePlayerEvent )
				A.Trigger( Self, Pawn(Other) );
		}
	}
	if ( bMoveProjectiles && (ZoneVelocity != vect(0,0,0)) )
	{
		if ( Other.Physics == PHYS_Projectile )
			Other.Velocity += ZoneVelocity;
		else if ( Other.IsA('Effects') && (Other.Physics == PHYS_None) )
		{
			Other.SetPhysics(PHYS_Projectile);
			Other.Velocity += ZoneVelocity;
		}
	}
}

// When an actor leaves this zone.
event ActorLeaving( actor Other )
{
	local actor A;

	if( Pawn(Other)!=None && Pawn(Other).bIsPlayer && !Pawn(Other).IsA('Spectator'))
	{
		if( --ZonePlayerCount < 1 )
		{
			ZonePlayerCount = 0;
			if( ZonePlayerEvent!='' )
				foreach AllActors( class 'Actor', A, ZonePlayerEvent )
					A.UnTrigger( Self, Pawn(Other) );
		}
	}
}

function Timer()
{
	local bool bEmpty;
	local actor A;
	local Pawn P;

	bEmpty = true;
	for ( P=Level.PawnList; P!=None; P=P.NextPawn )
	{
		// Ensure player hasn't been dispatched through other means already (suicide?)
		if( (P.Region.Zone == self) && (P.Health > 0) && !P.IsA('Spectator') )
			bEmpty = false;
	}
	if( bEmpty )
	{
		ZonePlayerCount = 0;
		if( ZonePlayerEvent!='' )
			foreach AllActors( class 'Actor', A, ZonePlayerEvent )
				A.UnTrigger( Self, none );
	}
	else
	{
		SetTimer( 0.5, false );
	}
}

defaultproperties
{
     bStatic=False
}
