//=============================================================================
// ZoomScope2 for UT.  By Dawn Knight version 1.03 09/08/2004
// A Zoom function for DawnsScopeCam using AltFire.
//
// When a DawnsScopeCam is Spawned ingame, it Spawns this ZoomScope2 and gives
// it to its TournamentPlayer Owner.  When the DawnsScopeCam is Destroyed, it
// takes this ZoomScope2 away and Destroys it, too.
//=============================================================================
class ZoomScope2 extends TournamentWeapon;

#exec texture IMPORT NAME=ScopeVisor FILE=..\Textures\Images\DawnsDeepSpace\ScopeVisor1e.PCX MIPS=OFF
#exec texture IMPORT NAME=Reticle FILE=..\Textures\Images\DawnsDeepSpace\Reticle1.PCX MIPS=OFF

#exec texture IMPORT NAME=UseZScope FILE=..\Textures\Images\DawnsDeepSpace\UseZScope.PCX MIPS=OFF

var int NumFire;
var name FireAnims[5];
var vector OwnerLocation;
var float StillTime, StillStart;
var Weapon PreviousWeapon;

var color ScopeVisorColor;
var color ReticleColor;
var int RetCnt;
var float RetScale;
var int RetFlashCnt;

simulated function PostRender( canvas Canvas )
{
	local PlayerPawn P;
	local float Scale;

	Super.PostRender(Canvas);
	P = PlayerPawn(Owner);
	if( (P == none) )
	{
		bOwnsCrossHair = false;
		return;
	}
	bOwnsCrossHair = true;
	Canvas.bNoSmooth = False;
	Canvas.SetPos(0, 0);
	Canvas.Style = ERenderStyle.STY_Translucent;
	Canvas.DrawColor = ScopeVisorColor;
	Canvas.DrawTile(texture'ScopeVisor', Canvas.Clipx, Canvas.ClipY, 0, 0, 256, 256);
	Canvas.DrawColor = ReticleColor;
	if( RetScale < 0.25 )
	{
		RetScale = 0.25;
		RetCnt++;
		if( RetCnt > 19 )
		{
			RetCnt = 0;
			RetFlashCnt++;
		}
	}
	if( RetFlashCnt > 8 )
	{
		Retscale = default.RetScale;
		RetCnt = 0;
		RetFlashCnt = 0;
	}
	Canvas.SetPos(Canvas.ClipX/2 - RetScale*Canvas.Clipx/4,
			Canvas.ClipY/2 - RetScale*Canvas.ClipY/4);
	if( RetCnt < 10 || RetFlashCnt > 3)
		Canvas.DrawTile(texture'Reticle', RetScale*Canvas.Clipx/2,
				RetScale*Canvas.ClipY/2, 0, 0, 128, 128);
	RetScale *= 0.98;
	Canvas.SetPos(0.5 * Canvas.ClipX + 20, 0.5 * Canvas.ClipY + 25);
	scale = P.DefaultFOV/P.DesiredFOV;
	Canvas.DrawText("X"$int(Scale)$"."$int(10 * scale - 10 * int(Scale)));
	Canvas.bNoSmooth = True;
	Canvas.Style = Style;
}

function float RateSelf( out int bUseAltMode )
{
	return -2;
}

function setHand(float Hand)
{
	Super.SetHand(Hand);
		mesh = mesh'Rifle2m';
}

simulated function PlayFiring()
{
}


function ForceFire()
{
}

simulated function bool ClientFire( float Value )
{
	return false;
}

function Fire( float Value )
{
}

simulated function bool ClientAltFire( float Value )
{
	GotoState('Zooming');
	return true;
}

function AltFire( float Value )
{
	ClientAltFire(Value);
}

function ReturnToPreviousWeapon()
{
	if ( (PreviousWeapon == None)
		|| ((PreviousWeapon.AmmoType != None) && (PreviousWeapon.AmmoType.AmmoAmount <=0)) )
		Pawn(Owner).SwitchToBestWeapon();
	else
	{
		Pawn(Owner).PendingWeapon = PreviousWeapon;
		PutDown();
	}
}

simulated function PlayIdleAnim()
{
	if ( Mesh != PickupViewMesh )
		PlayAnim('Still',1.0, 0.05);
}

///////////////////////////////////////////////////////
state NormalFire
{
	function ForceFire()
	{
	}

	function Fire( float Value )
	{
	}

	function EndState()
	{
		Super.EndState();
		OldFlashCount = FlashCount;
	}

Begin:
	FlashCount++;
}

function Timer()
{
	local actor targ;
	local float bestAim, bestDist;
	local vector FireDir;
	local Pawn P;

	bestAim = 0.95;
	P = Pawn(Owner);
	if ( P == None )
	{
		GotoState('');
		return;
	}
	if ( VSize(P.Location - OwnerLocation) < 6 )
		StillTime += FMin(2.0, Level.TimeSeconds - StillStart);

	else
		StillTime = 0;
	StillStart = Level.TimeSeconds;
	OwnerLocation = P.Location;
	FireDir = vector(P.ViewRotation);
	targ = P.PickTarget(bestAim, bestDist, FireDir, Owner.Location);
	if ( Pawn(targ) != None )
	{
		SetTimer(1 + 4 * FRand(), false);
		bPointing = true;
		Pawn(targ).WarnTarget(P, 200, FireDir);
	}
	else
	{
		SetTimer(0.4 + 1.6 * FRand(), false);
		if ( (P.bFire == 0) && (P.bAltFire == 0) )
			bPointing = false;
	}
}

function ProcessTraceHit(Actor Other, Vector HitLocation, Vector HitNormal, Vector X, Vector Y, Vector Z)
{
}

function Finish()
{
	if ( (Pawn(Owner).bFire!=0) && (FRand() < 0.6) )
		Timer();
	Super.Finish();
}

function TraceFire( float Accuracy )
{
}

///////////////////////////////////////////////////////
state Idle
{
	function ForceFire()
	{
	}

	function Fire( float Value )
	{
	}


	function BeginState()
	{
		bPointing = false;
		SetTimer(0.4 + 1.6 * FRand(), false);
		Super.BeginState();
	}

	function EndState()
	{
		SetTimer(0.0, false);
		Super.EndState();
	}

Begin:
	bPointing=False;
	if ( AmmoType.AmmoAmount<=0 )
		Pawn(Owner).SwitchToBestWeapon();
	if ( Pawn(Owner).bFire!=0 ) Fire(0.0);
	Disable('AnimEnd');
	PlayIdleAnim();
}

///////////////////////////////////////////////////////
state Zooming
{
	simulated function Tick(float DeltaTime)
	{
		if ( Pawn(Owner).bAltFire == 0 )
		{
			if ( (PlayerPawn(Owner) != None) && PlayerPawn(Owner).Player.IsA('ViewPort') )
				PlayerPawn(Owner).StopZoom();
			SetTimer(0.0,False);
			GoToState('Idle');
		}
	}

	simulated function BeginState()
	{
		if ( Owner.IsA('PlayerPawn') )
		{
			if ( PlayerPawn(Owner).Player.IsA('ViewPort') )
				PlayerPawn(Owner).ToggleZoom();
			SetTimer(0.2,True);
		}
	}
}

///////////////////////////////////////////////////////////

defaultproperties
{
     ReticleColor=(R=15,G=95,B=15)
     RetScale=1.75
     ScopeVisorColor=(R=63,G=15,B=15)
     FireAnims(0)=Fire
     FireAnims(1)=Fire2
     FireAnims(2)=Fire3
     FireAnims(3)=Fire4
     FireAnims(4)=Fire5
     WeaponDescription="Regular Fire: None. \n\nSecondary Fire: Zooms, up to eight times normal vision."
     AmmoName=Class'Botpack.BulletBox'
     PickupAmmoCount=8
     bInstantHit=True
     bAltInstantHit=True
     FiringSpeed=1.800000
     FireOffset=(Y=-5.000000,Z=-2.000000)
     MyDamageType=shot
     AltDamageType=Decapitated
     shakemag=0.000000
     shaketime=0.000000
     shakevert=0.000000
     AIRating=0.540000
     RefireRate=0.600000
     AltRefireRate=0.300000
     FireSound=Sound'Botpack.SniperRifle.SniperFire'
     SelectSound=Sound'UnrealI.Rifle.RiflePickup'
     DeathMessage="%k put a bullet through %o's head."
     NameColor=(R=0,G=0)
     bDrawMuzzleFlash=True
     MuzzleScale=1.000000
     FlashY=0.110000
     FlashO=0.014000
     FlashC=0.031000
     FlashLength=0.013000
     FlashS=256
     MFTexture=Texture'None'
     AutoSwitchPriority=10
     InventoryGroup=7
     PickupMessage="Zoom Function."
     ItemName="Zoom Scope"
     PlayerViewOffset=(X=5.000000,Y=-1.600000,Z=-1.700000)
     PlayerViewMesh=LodMesh'Botpack.Rifle2m'
     PlayerViewScale=0.000001
     BobDamping=0.975000
     PickupViewMesh=LodMesh'Botpack.RiflePick'
     PickupViewScale=0.000001
     ThirdPersonMesh=LodMesh'Botpack.RifleHand'
     ThirdPersonScale=0.000001
     StatusIcon=Texture'UseZScope'
     bMuzzleFlashParticles=False
     MuzzleFlashStyle=STY_Translucent
     MuzzleFlashMesh=LodMesh'Botpack.muzzsr3'
     MuzzleFlashScale=0.000001
     MuzzleFlashTexture=Texture'Botpack.Skins.Muzzy3'
     PickupSound=Sound'UnrealShare.Pickups.WeaponPickup'
     Icon=Texture'UseZScope'
     Rotation=(Roll=-1536)
     Mesh=LodMesh'Botpack.RiflePick'
     bNoSmooth=False
     CollisionRadius=32.000000
     CollisionHeight=8.000000
}
